==> elara-core-1.3-sources.jar: org/tools4j/elara/plugin/timer/TimerPayloadDescriptor.java <==
/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2020 tools4j.org (Marco Terzer, Anton Anufriev)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.tools4j.elara.plugin.timer;

/**
 * Descriptor of payload layout for time events in a byte buffer.
 * <pre>

 0         1         2         3         4         5         6
 0 2 4 6 8 0 2 4 6 8 0 2 4 6 8 0 2 4 6 8 0 2 4 6 8 0 2 4 6 8 0 2 4
 +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 |                           Timer ID                            |
 +-------+-------+-------+-------+-------+-------+-------+-------+
 |          Timer Type           |           Repetition          |
 +-------+-------+-------+-------+-------+-------+-------+-------+
 |                            Timeout                            |
 +-------+-------+-------+-------+-------+-------+-------+-------+

 * </pre>
 */
public enum TimerPayloadDescriptor {
    ;

    public static final int TIMER_ID_OFFSET = 0;
    public static final int TIMER_ID_LENGTH = Long.BYTES;
    public static final int TIMER_TYPE_OFFSET = TIMER_ID_OFFSET + TIMER_ID_LENGTH;
    public static final int TIMER_TYPE_LENGTH = Integer.BYTES;
    public static final int TIMER_REPETITION_OFFSET = TIMER_TYPE_OFFSET + TIMER_TYPE_LENGTH;
    public static final int TIMER_REPETITION_LENGTH = Integer.BYTES;
    public static final int TIMER_TIMEOUT_OFFSET = TIMER_REPETITION_OFFSET + TIMER_REPETITION_LENGTH;
    public static final int TIMER_TIMEOUT_LENGTH = Long.BYTES;

    public static final int PAYLOAD_SIZE = TIMER_TIMEOUT_OFFSET + TIMER_TIMEOUT_LENGTH;

}

==> elara-core-1.7-sources.jar: org/tools4j/elara/plugin/timer/TimerPayloadDescriptor.java <==
/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2020 tools4j.org (Marco Terzer, Anton Anufriev)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.tools4j.elara.plugin.timer;

import org.agrona.DirectBuffer;

/**
 * Descriptor of payload layout for timer commands and events in a byte buffer.
 * <pre>

 0         1         2         3         4         5         6
 0 2 4 6 8 0 2 4 6 8 0 2 4 6 8 0 2 4 6 8 0 2 4 6 8 0 2 4 6 8 0 2 4
 +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 |                           Timer ID                            |
 +-------+-------+-------+-------+-------+-------+-------+-------+
 |          Timer Type           |           Repetition          |
 +-------+-------+-------+-------+-------+-------+-------+-------+
 |                            Timeout                            |
 +-------+-------+-------+-------+-------+-------+-------+-------+

 * </pre>
 */
public enum TimerPayloadDescriptor {
    ;

    public static final int TIMER_ID_OFFSET = 0;
    public static final int TIMER_ID_LENGTH = Long.BYTES;
    public static final int TIMER_TYPE_OFFSET = TIMER_ID_OFFSET + TIMER_ID_LENGTH;
    public static final int TIMER_TYPE_LENGTH = Integer.BYTES;
    public static final int TIMER_REPETITION_OFFSET = TIMER_TYPE_OFFSET + TIMER_TYPE_LENGTH;
    public static final int TIMER_REPETITION_LENGTH = Integer.BYTES;
    public static final int TIMER_TIMEOUT_OFFSET = TIMER_REPETITION_OFFSET + TIMER_REPETITION_LENGTH;
    public static final int TIMER_TIMEOUT_LENGTH = Long.BYTES;

    public static final int PAYLOAD_SIZE = TIMER_TIMEOUT_OFFSET + TIMER_TIMEOUT_LENGTH;

    public static long timerId(final DirectBuffer payload) {
        return payload.getLong(TIMER_ID_OFFSET);
    }

    public static int timerType(final DirectBuffer payload) {
        return payload.getInt(TIMER_TYPE_OFFSET);
    }

    public static int timerRepetition(final DirectBuffer payload) {
        return payload.getInt(TIMER_REPETITION_OFFSET);
    }

    public static long timerTimeout(final DirectBuffer payload) {
        return payload.getLong(TIMER_TIMEOUT_OFFSET);
    }
}
